@@ -122,11 +122,10 @@ class IConcreteClassProvider(Interface):
             'search': search for objects of this class.
         
         :param key_str: optional, the object's key, in the form of a string representing 
-                        a dictionary. To get this string, use the 
-                        get_string_from_dictionary() function in the
+                        a dictionary. To get a dictionary back from this string, use the 
+                        get_dictionary_from_string() function in the
                         tracgenericclass.util package.
-        :param operation: optional, the operatyion to be performed on the object.
-                          TODO: specify the list of available operations.
+        :param operation: optional, the operation to be performed on the object.
         :param name: optional property name, valid for the 'set' operation type
         :param value: optional property value, valid for the 'set' operation type
         """
@@ -747,7 +746,7 @@ class AbstractVariableFieldsObject(object):
         """
         pass
             
-    def list_matching_objects(self, db=None):
+    def list_matching_objects(self, exact_match=True, db=None):
         """
         List the objects that match the current values of this object's
         fields.
@@ -756,6 +755,9 @@ class AbstractVariableFieldsObject(object):
         match on, then call this method.
         A collection of objects found in the database matching the 
         fields you had provided values for will be returned.
+        An exact match, i.e. an SQL '=' operator, will be used, unless you
+        specify exact_match=False, in which case the SQL 'LIKE' operator
+        will be used.
         
         The `db` argument is deprecated in favor of `with_transaction()`.
         """
@@ -773,11 +775,15 @@ class AbstractVariableFieldsObject(object):
         non_empty_std_values = self.get_values(non_empty_std_names)
         non_empty_custom_values = self.get_values(non_empty_custom_names)
 
+        operator = '='
+        if not exact_match:
+            operator = ' LIKE '
+        
         sql_where = '1=1'
         for k in non_empty_std_names:
-            sql_where += " AND " + k + "=%%s" 
+            sql_where += " AND " + k + operator + '%%s'
         
-        cursor.execute(("SELECT %s FROM %s WHERE " + sql_where)
+        cursor.execute(('SELECT %s FROM %s WHERE ' + sql_where)
                        % (','.join(self.get_key_prop_names()), self.realm), 
                        non_empty_std_values)
 
@@ -941,6 +947,8 @@ class AbstractWikiPageWrapper(AbstractVariableFieldsObject):
         wikipage.text = self.text
         wikipage.save(self.author, '', self.remote_addr)
     
+        print("YEEEES!!!")
+    
         self.wikipage = wikipage
 
         return True
